import { useQuery } from "h3";
import { fetchReleases, overrideConfig, parseRelease } from "../../utils/queries.mjs";
import * as imports from "#imports";
let handler;
if (process.env.NODE_ENV === "development") {
  handler = imports.defineEventHandler;
} else {
  handler = imports.defineCachedEventHandler;
}
export default handler(async ({ req }) => {
  const moduleConfig = imports.useRuntimeConfig().github;
  const query = useQuery(req);
  const githubConfig = overrideConfig(moduleConfig, query);
  if (!githubConfig.owner || !githubConfig.repo || !githubConfig.api) {
    return [];
  }
  let releases = await fetchReleases(query, githubConfig);
  if (!releases) {
    return;
  }
  if (moduleConfig.parseContents) {
    releases = await Promise.all(releases.map((release) => parseRelease(release, githubConfig)));
  }
  releases = (releases || []).sort((a, b) => a.v !== b.v ? b.v - a.v : a.date - b.date);
  return releases;
}, {
  maxAge: 60
});
